
%global pkg_name ormolu
%global pkgver %{pkg_name}-%{version}

%global thenv th-env-0.1.1
%global markdownunlit markdown-unlit-0.5.1
%global subpkgs %{markdownunlit} %{thenv}

%bcond_with tests

Name:           %{pkg_name}
Version:        0.5.3.0
Release:    1%{?dist}
Summary:        A formatter for Haskell source code

License:        BSD-3-Clause
Url:            https://hackage.haskell.org/package/%{name}
Source0:        https://hackage.haskell.org/package/%{pkgver}/%{pkgver}.tar.gz
Source1:        https://hackage.haskell.org/package/%{thenv}/%{thenv}.tar.gz
Source2:        https://hackage.haskell.org/package/%{markdownunlit}/%{markdownunlit}.tar.gz
Source3:        https://hackage.haskell.org/package/%{pkgver}/%{name}.cabal#/%{pkgver}.cabal

BuildRequires:  dos2unix
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros-extra
BuildRequires:  ghc-Cabal-syntax-devel
BuildRequires:  ghc-Diff-devel
BuildRequires:  ghc-MemoTrie-devel
BuildRequires:  ghc-ansi-terminal-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-binary-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-dlist-devel
BuildRequires:  ghc-file-embed-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-ghc-lib-parser-devel
BuildRequires:  ghc-megaparsec-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-optparse-applicative-devel
BuildRequires:  ghc-syb-devel
BuildRequires:  ghc-text-devel
%if %{with ghc_prof}
BuildRequires:  ghc-Cabal-syntax-prof
BuildRequires:  ghc-Diff-prof
BuildRequires:  ghc-MemoTrie-prof
BuildRequires:  ghc-ansi-terminal-prof
BuildRequires:  ghc-array-prof
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-binary-prof
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-directory-prof
BuildRequires:  ghc-dlist-prof
BuildRequires:  ghc-file-embed-prof
BuildRequires:  ghc-filepath-prof
BuildRequires:  ghc-ghc-lib-parser-prof
BuildRequires:  ghc-megaparsec-prof
BuildRequires:  ghc-mtl-prof
BuildRequires:  ghc-optparse-applicative-prof
BuildRequires:  ghc-syb-prof
BuildRequires:  ghc-text-prof
%endif
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-hspec-discover-devel
BuildRequires:  ghc-hspec-megaparsec-devel
BuildRequires:  ghc-path-devel
BuildRequires:  ghc-path-io-devel
BuildRequires:  ghc-temporary-devel
%endif
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-th-compat-devel
%if %{with ghc_prof}
BuildRequires:  ghc-template-haskell-prof
BuildRequires:  ghc-th-compat-prof
%endif
BuildRequires:  ghc-base-compat-devel
%if %{with ghc_prof}
BuildRequires:  ghc-base-compat-prof
%endif

%description
Ormolu is a formatter for Haskell source code.
The project was created with the following goals in mind:

- Using GHC's own parser to avoid parsing problems caused by haskell-src-exts.

- Let some whitespace be programmable. The layout of the input
  influences the layout choices in the output. This means that the
  choices between single-line/multi-line layouts in each particular
  situation are made by the user, not by an algorithm. This makes the
  implementation simpler and leaves some control to the user while
  still guaranteeing that the formatted code is stylistically
  consistent.

- Writing code in such a way so it's easy to modify and maintain.

- Implementing one “true” formatting style which admits no configuration.

- That formatting style aims to result in minimal diffs while still
  remaining very close to “conventional” Haskell formatting people
  use.

- Choose a style compatible with modern dialects of Haskell. As new
  Haskell extensions enter broad use, we may change the style to
  accommodate them.

- Idempotence: formatting already formatted code doesn't change it.

- Be well-tested and robust to the point that it can be used in large
  projects without exposing unfortunate, disappointing bugs here and
  there.


%package -n ghc-%{name}
Summary:        Haskell %{name} library

%description -n ghc-%{name}
This package provides the Haskell %{name} shared library.


%package -n ghc-%{name}-devel
Summary:        Haskell %{name} library development files
Provides:       ghc-%{name}-static = %{version}-%{release}
Provides:       ghc-%{name}-static = %{version}-%{release}
%if %{defined ghc_version}
Requires:       ghc-compiler = %{ghc_version}
%endif
Requires:       ghc-%{name} = %{version}-%{release}

%description -n ghc-%{name}-devel
This package provides the Haskell %{name} library development files.


%if %{with haddock}
%package -n ghc-%{name}-doc
Summary:        Haskell %{name} library documentation
BuildArch:      noarch
Requires:       ghc-filesystem

%description -n ghc-%{name}-doc
This package provides the Haskell %{name} library documentation.
%endif


%if %{with ghc_prof}
%package -n ghc-%{name}-prof
Summary:        Haskell %{name} profiling library
Requires:       ghc-%{name}-devel = %{version}-%{release}
Supplements:    (ghc-%{name}-devel and ghc-prof)

%description -n ghc-%{name}-prof
This package provides the Haskell %{name} profiling library.
%endif


%global main_version %{version}

%if %{defined ghclibdir}
%ghc_lib_subpackage -l BSD-3-Clause %{thenv}
%ghc_lib_subpackage -l MIT %{markdownunlit}
%endif

%global version %{main_version}


%prep
%setup -q -a1 -a2
dos2unix -k -n %{SOURCE3} %{name}.cabal


%build
%ghc_libs_build %{subpkgs}
%ghc_lib_build


%install
%ghc_libs_install %{subpkgs}
%ghc_lib_install
mkdir -p %{buildroot}%{_datadir}/bash-completion/completions/
%{buildroot}%{_bindir}/%{name} --bash-completion-script %{name} | sed s/filenames/default/ > %{buildroot}%{_datadir}/bash-completion/completions/%{name}

echo %{_bindir}/markdown-unlit >> %{markdownunlit}/ghc-markdown-unlit.files


%check
%if %{with tests}
%cabal_test
%endif


%files
%license LICENSE.md
%doc CHANGELOG.md CONTRIBUTING.md README.md
%{_bindir}/%{name}
%{_datadir}/bash-completion/completions/%{name}


%files -n ghc-%{name} -f ghc-%{name}.files
%license LICENSE.md


%files -n ghc-%{name}-devel -f ghc-%{name}-devel.files
%doc CHANGELOG.md CONTRIBUTING.md README.md


%if %{with haddock}
%files -n ghc-%{name}-doc -f ghc-%{name}-doc.files
%license LICENSE.md
%endif


%if %{with ghc_prof}
%files -n ghc-%{name}-prof -f ghc-%{name}-prof.files
%endif


%changelog
* Mon Apr 15 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.5.3.0-1
- initial build
